//  gmodconfig - a Gnome based kernel module configuration tool
//  http://gmodconfig.sourceforge.net/
//  Copyright (C) 2003 Cyril Bortolato
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//  testxsaget.cpp: unit test program for the XSA download functionality
//--------------------------------------------------------------------------//

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <iostream>
using std::cout;
using std::endl;

#include <libgnomevfs/gnome-vfs.h>
#include "xsareader.h"
#include "xsatypes.h"
#include <unistd.h>

using namespace gmodcfg;

static gint
progressCallback( GnomeVFSXferProgressInfo *info, gpointer data )
{
    if ( info->status != GNOME_VFS_XFER_PROGRESS_STATUS_OK )
        cout << "Problem" << endl;
    return 1;
}

static void
printResult( GnomeVFSResult result )
{
    cout << "Result is: " << gnome_vfs_result_to_string( result ) << endl;
}

int main()
{
    if ( !gnome_vfs_init() )
    {
        cout << "Could not initialize GnomeVFS" << endl;
        return 1;
    }

    char* src = "http://gmodconfig.sourceforge.net/tests/ov511.xsa";
    char* dest = "file:///tmp/file.xsa";
    GnomeVFSURI* srcUri = gnome_vfs_uri_new( src );
    GnomeVFSURI* destUri = gnome_vfs_uri_new( dest );

    GnomeVFSResult result = gnome_vfs_xfer_uri( srcUri, destUri,
            GNOME_VFS_XFER_DEFAULT,
            GNOME_VFS_XFER_ERROR_MODE_QUERY,
            GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
            progressCallback, NULL );
    cout << "Result is: " << gnome_vfs_result_to_string( result ) << endl;

    return result != GNOME_VFS_OK;
}

